diff api/Factories/AbstractWarFoundryFactory.cs @ 120:fcbc3beea498

* Change default factory behaviour to pretend it has loaded files without changing anything no-open-ticket
author IBBoard <dev@ibboard.co.uk>
date Sun, 23 Aug 2009 11:03:09 +0000
parents 2f3cafb69799
children 1d13820b3d96
line wrap: on
line diff
--- a/api/Factories/AbstractWarFoundryFactory.cs	Sun Aug 23 10:32:09 2009 +0000
+++ b/api/Factories/AbstractWarFoundryFactory.cs	Sun Aug 23 11:03:09 2009 +0000
@@ -13,7 +13,8 @@
 	{		
 		public virtual void CompleteLoading(IWarFoundryStagedLoadObject obj)
 		{
-			//Default to doing nothing as this will probably be standard for non-native factories and some native factories
+			//Pretend we've fully loaded, as this will probably be standard for non-native factories and some native factories
+			obj.SetAsFullyLoaded();
 		}
 			
 		public bool CanHandleFileFormat (FileInfo file)